@@ -1,6 +1,8 @@
 #' Data model class
 #'
 #' @description
+#' `r lifecycle::badge("stable")`
+#'
 #' The `dm` class holds a list of tables and their relationships.
 #' It is inspired by [datamodelr](https://github.com/bergant/datamodelr),
 #' and extends the idea by offering operations to access the data in the tables.
@@ -18,7 +20,7 @@
 #'
 #' @seealso
 #'
-#' - [dm_from_src()] for connecting to all tables in a database
+#' - [dm_from_con()] for connecting to all tables in a database
 #'   and importing the primary and foreign keys
 #' - [dm_add_pk()] and [dm_add_fk()] for adding primary and foreign keys
 #' - [copy_dm_to()] for DB interaction
@@ -34,26 +36,23 @@
 #' @export
 #' @examples
 #' dm(trees, mtcars)
+#'
 #' new_dm(list(trees = trees, mtcars = mtcars))
+#'
 #' as_dm(list(trees = trees, mtcars = mtcars))
 #' @examplesIf rlang::is_installed("nycflights13") && rlang::is_installed("dbplyr")
 #'
+#' is_dm(dm_nycflights13())
+#'
 #' dm_nycflights13()$airports
+#'
+#' dm_nycflights13()["airports"]
+#'
+#' dm_nycflights13()[["airports"]]
+#'
 #' dm_nycflights13() %>% names()
 #'
-#' copy_dm_to(
-#'   dbplyr::src_memdb(),
-#'   dm_nycflights13()
-#' ) %>%
-#'   dm_get_con()
-#'
 #' dm_nycflights13() %>% dm_get_tables()
-#' dm_nycflights13() %>% dm_get_filters()
-#' dm_nycflights13() %>% validate_dm()
-#' is_dm(dm_nycflights13())
-#' dm_nycflights13()["airports"]
-#' dm_nycflights13()[["airports"]]
-#' dm_nycflights13()$airports
 dm <- function(..., .name_repair = c("check_unique", "unique", "universal", "minimal")) {
   quos <- enquos(...)
 
@@ -62,14 +61,14 @@ dm <- function(..., .name_repair = c("check_unique", "unique", "universal", "min
   if (has_length(quos)) {
     src_index <- c(which(names(quos) == "src"), 1)[[1]]
     if (is.src(tbls[[src_index]])) {
-      deprecate_soft("0.0.4.9001", "dm::dm(src = )", "dm_from_src()")
-      return(invoke(dm_from_src, tbls))
+      deprecate_soft("0.0.4.9001", "dm::dm(src = )")
+      return(exec(dm_from_con, con_from_src_or_con(tbls[[src_index]]), !!!tbls[-src_index]))
     }
   }
 
   names(tbls) <- vec_as_names(names(quos_auto_name(quos)), repair = .name_repair)
   dm <- new_dm(tbls)
-  validate_dm(dm)
+  dm_validate(dm)
   dm
 }
 
@@ -82,7 +81,7 @@ dm <- function(..., .name_repair = c("check_unique", "unique", "universal", "min
 #'
 #' - If called with arguments, no validation checks will be made to ascertain that
 #'   the inputs are of the expected class and internally consistent;
-#'   use `validate_dm()` to double-check the returned object.
+#'   use [dm_validate()] to double-check the returned object.
 #'
 #' @param tables A named list of the tables (tibble-objects, not names),
 #'   to be included in the `dm` object.
@@ -94,23 +93,19 @@ new_dm <- function(tables = list()) {
 }
 
 new_dm2 <- function(tables = list(),
-                    pks = structure(list(), names = character()),
-                    fks = structure(list(), names = character()),
+                    pks_df = tibble(table = character(), pks = list()),
+                    fks_df = tibble(table = character(), fks = list()),
                     validate = TRUE) {
   # Legacy
   data <- unname(tables)
   table <- names2(tables)
 
-  stopifnot(!is.null(names(pks)), all(names(pks) %in% table))
-  stopifnot(!is.null(names(fks)), all(names(fks) %in% table))
+  stopifnot(all(pks_df$table %in% table))
+  stopifnot(all(fks_df$table %in% table))
 
   zoom <- new_zoom()
   col_tracker_zoom <- new_col_tracker_zoom()
 
-  pks_df <- enframe(pks, "table", "pks")
-
-  fks_df <- enframe(fks, "table", "fks")
-
   filters <-
     tibble(
       table = table,
@@ -138,7 +133,7 @@ new_dm3 <- function(def, zoomed = FALSE, validate = TRUE) {
   out <- structure(list(def = def), class = class, version = 2L)
 
   # Enable for strict tests (search for INSTRUMENT in .github/workflows):
-  # if (validate) { validate_dm(out) } # INSTRUMENT: validate
+  # if (validate) { dm_validate(out) } # INSTRUMENT: validate
 
   out
 }
@@ -181,38 +176,12 @@ new_col_tracker_zoom <- function() {
   tibble(table = character(), col_tracker_zoom = list())
 }
 
-dm_get_src_impl <- function(x) {
-  tables <- dm_get_tables_impl(x)
-  tbl_src(tables[1][[1]])
-}
-
-#' Get connection
-#'
-#' `dm_get_con()` returns the DBI connection for a `dm` object.
-#' This works only if the tables are stored on a database, otherwise an error
-#' is thrown.
-#'
-#' All lazy tables in a dm object must be stored on the same database server
-#' and accessed through the same connection.
-#'
-#' @rdname dm
-#'
-#' @return For `dm_get_con()`: The [`DBI::DBIConnection-class`] for `dm` objects.
-#'
-#' @export
-dm_get_con <- function(x) {
-  check_not_zoomed(x)
-  src <- dm_get_src_impl(x)
-  if (!inherits(src, "src_dbi")) abort_con_only_for_dbi()
-  src$con
-}
-
 #' Get tables
 #'
 #' `dm_get_tables()` returns a named list of \pkg{dplyr} [tbl] objects
 #' of a `dm` object.
-#' Filtering expressions are NOT evaluated at this stage.
-#' To get a filtered table, use `dm_apply_filters_to_tbl()`, to apply filters to all tables use `dm_apply_filters()`
+#' Filtering expressions defined by [dm_filter()] are NOT evaluated at this stage.
+#' To get a filtered table, use [dm_apply_filters_to_tbl()], to apply filters to all tables use [dm_apply_filters()].
 #'
 #' @rdname dm
 #'
@@ -245,40 +214,6 @@ unnest_pks <- function(def) {
   pk_df
 }
 
-#' Get filter expressions
-#'
-#' `dm_get_filters()` returns the filter expressions that have been applied to a `dm` object.
-#' These filter expressions are not intended for evaluation, only for
-#' information.
-#'
-#' @inheritParams dm
-#'
-#' @return A tibble with the following columns:
-#'   \describe{
-#'     \item{`table`}{table that was filtered,}
-#'     \item{`filter`}{the filter expression,}
-#'     \item{`zoomed`}{logical, does the filter condition relate to the zoomed table.}
-#'   }
-#'
-#' @export
-dm_get_filters <- function(x) {
-  check_not_zoomed(x)
-
-  filter_df <-
-    dm_get_def(x) %>%
-    select(table, filters) %>%
-    unnest_list_of_df("filters")
-
-  # FIXME: Should work better with dplyr 0.9.0
-  if (!("filter_expr" %in% names(filter_df))) {
-    filter_df$filter_expr <- list()
-  }
-
-  filter_df %>%
-    rename(filter = filter_expr) %>%
-    mutate(filter = unname(filter))
-}
-
 dm_get_zoom <- function(x, cols = c("table", "zoom"), quiet = FALSE) {
   # Performance
   def <- dm_get_def(x, quiet)
@@ -295,9 +230,11 @@ dm_get_zoom <- function(x, cols = c("table", "zoom"), quiet = FALSE) {
 #'
 #' `is_dm()` returns `TRUE` if the input is of class `dm`.
 #'
+#' @param x An object.
+#'
 #' @rdname dm
 #'
-#' @return For `is_dm()`: Boolean, is this object a `dm`.
+#' @return For `is_dm()`: A scalar logical, `TRUE` if is this object is a `dm`.
 #'
 #' @export
 is_dm <- function(x) {
@@ -324,7 +261,7 @@ as_dm.default <- function(x) {
   # Automatic name repair
   names(x) <- vec_as_names(names2(x), repair = "unique")
   dm <- new_dm(x)
-  validate_dm(dm)
+  dm_validate(dm)
   dm
 }
 
@@ -340,11 +277,17 @@ tbl_src <- function(x) {
 
 #' @export
 as_dm.src <- function(x) {
-  dm_from_src(src = x, table_names = NULL)
+  dm_from_con(con = con_from_src_or_con(x), table_names = NULL)
 }
 
 #' @export
-print.dm <- function(x, ...) { # for both dm and zoomed_dm
+as_dm.DBIConnection <- function(x) {
+  dm_from_con(con = x, table_names = NULL)
+}
+
+#' @export
+print.dm <- function(x, ...) {
+  # for both dm and zoomed_dm
   show_dm(x)
   invisible(x)
 }
@@ -366,8 +309,7 @@ show_dm <- function(x) {
     cat_rule("Table source", col = "green")
     db_info <- NULL
 
-    # FIXME: change to pillar::tbl_sum() once it's there
-    tbl_str <- tibble::tbl_sum(def$data[[1]])
+    tbl_str <- pillar::tbl_sum(def$data[[1]])
     if ("Database" %in% names(tbl_str)) {
       db_info <- paste0("src:  ", tbl_str[["Database"]])
     }
@@ -393,7 +335,8 @@ show_dm <- function(x) {
 }
 
 #' @export
-format.dm <- function(x, ...) { # for both dm and zoomed_dm
+format.dm <- function(x, ...) {
+  # for both dm and zoomed_dm
   def <- dm_get_def(x)
   glue("dm: {def_get_n_tables(def)} tables, {def_get_n_columns(def)} columns, {def_get_n_pks(def)} primary keys, {def_get_n_fks(def)} foreign keys")
 }
@@ -440,10 +383,7 @@ new_zoomed_df <- function(x, ...) {
   # in print method for local tibbles
   new_tibble(
     x,
-    # need setdiff(...), because we want to keep everything "special" (like groups etc.) but drop
-    # all classes, that a `tbl` has anyway
-    # FIXME: Remove setdiff() when tibble >= 3.0.0 is on CRAN
-    class = c("zoomed_df", setdiff(class(x), c("tbl_df", "tbl", "data.frame"))),
+    class = c("zoomed_df", class(x), c("tbl_df", "tbl", "data.frame")),
     nrow = nrow(x),
     ...
   )
@@ -465,7 +405,8 @@ format.zoomed_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 }
 
 #' @export
-`$.dm` <- function(x, name) { # for both dm and zoomed_dm
+`$.dm` <- function(x, name) {
+  # for both dm and zoomed_dm
   table <- dm_tbl_name(x, {{ name }})
   tbl_impl(x, table)
 }
@@ -482,7 +423,8 @@ format.zoomed_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 }
 
 #' @export
-`[[.dm` <- function(x, id) { # for both dm and zoomed_dm
+`[[.dm` <- function(x, id) {
+  # for both dm and zoomed_dm
   if (is.numeric(id)) id <- src_tbls_impl(x)[id] else id <- as_string(id)
   tbl_impl(x, id, quiet = TRUE)
 }
@@ -505,7 +447,8 @@ format.zoomed_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 }
 
 #' @export
-`[.zoomed_dm` <- function(x, id) { # for both dm and zoomed_dm
+`[.zoomed_dm` <- function(x, id) {
+  # for both dm and zoomed_dm
   `[`(tbl_zoomed(x), id)
 }
 
@@ -516,7 +459,8 @@ format.zoomed_df <- function(x, ..., n = NULL, width = NULL, n_extra = NULL) {
 }
 
 #' @export
-names.dm <- function(x) { # for both dm and zoomed_dm
+names.dm <- function(x) {
+  # for both dm and zoomed_dm
   src_tbls_impl(x, quiet = TRUE)
 }
 
@@ -532,7 +476,8 @@ names.zoomed_dm <- function(x) {
 }
 
 #' @export
-length.dm <- function(x) { # for both dm and zoomed_dm
+length.dm <- function(x) {
+  # for both dm and zoomed_dm
   length(src_tbls_impl(x, quiet = TRUE))
 }
 
@@ -547,7 +492,8 @@ length.zoomed_dm <- function(x) {
 }
 
 #' @export
-str.dm <- function(object, ...) { # for both dm and zoomed_dm
+str.dm <- function(object, ...) {
+  # for both dm and zoomed_dm
   object <-
     dm_get_def(object, quiet = TRUE) %>%
     select(table, pks, fks, filters)
@@ -579,6 +525,9 @@ src_tbls_impl <- function(dm, quiet = FALSE) {
 
 #' Materialize
 #'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
 #' `compute()` materializes all tables in a `dm` to new (temporary or permanent)
 #' tables on the database.
 #'
@@ -609,7 +558,8 @@ src_tbls_impl <- function(dm, quiet = FALSE) {
 #'   collect() %>%
 #'   pull_tbl(districts) %>%
 #'   class()
-compute.dm <- function(x, ...) { # for both dm and zoomed_dm
+compute.dm <- function(x, ...) {
+  # for both dm and zoomed_dm
   x %>%
     dm_apply_filters() %>%
     dm_get_def() %>%
@@ -625,7 +575,8 @@ compute.dm <- function(x, ...) { # for both dm and zoomed_dm
 #'
 #' @rdname materialize
 #' @export
-collect.dm <- function(x, ..., progress = NA) { # for both dm and zoomed_dm
+collect.dm <- function(x, ..., progress = NA) {
+  # for both dm and zoomed_dm
   x <- dm_apply_filters(x)
 
   def <- dm_get_def(x)
@@ -645,12 +596,14 @@ collect.zoomed_dm <- function(x, ...) {
 
 # FIXME: what about 'dim.dm()'?
 #' @export
-dim.zoomed_dm <- function(x) { # dm method provided by base
+dim.zoomed_dm <- function(x) {
+  # dm method provided by base
   dim(tbl_zoomed(x, quiet = TRUE))
 }
 
 #' @export
-dimnames.zoomed_dm <- function(x) { # dm method provided by base
+dimnames.zoomed_dm <- function(x) {
+  # dm method provided by base
   dimnames(tbl_zoomed(x))
 }
 
@@ -695,7 +648,10 @@ empty_dm <- function() {
 
 #' Retrieve a table
 #'
-#' This function has methods for both `dm` classes:
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' This generic has methods for both `dm` classes:
 #' 1. With `pull_tbl.dm()` you can chose which table of the `dm` you want to retrieve.
 #' 1. With `pull_tbl.zoomed_dm()` you will retrieve the zoomed table in the current state.
 #'
@@ -719,7 +675,8 @@ pull_tbl <- function(dm, table) {
 }
 
 #' @export
-pull_tbl.dm <- function(dm, table) { # for both dm and zoomed_dm
+pull_tbl.dm <- function(dm, table) {
+  # for both dm and zoomed_dm
   # FIXME: shall we issue a special error in case someone tries sth. like: `pull_tbl(dm_for_filter, c(t4, t3))`?
   table_name <- as_string(enexpr(table))
   if (table_name == "") abort_no_table_provided()
@@ -744,7 +701,8 @@ pull_tbl.zoomed_dm <- function(dm, table) {
 }
 
 #' @export
-as.list.dm <- function(x, ...) { # for both dm and zoomed_dm
+as.list.dm <- function(x, ...) {
+  # for both dm and zoomed_dm
   dm_get_tables_impl(x)
 }
 
@@ -753,56 +711,180 @@ as.list.zoomed_dm <- function(x, ...) {
   as.list(tbl_zoomed(x))
 }
 
+#' Get a glimpse of your `dm` object
+#'
+#' @param x A `dm` object.
+#' @param width Controls the maximum number of columns on a line used in
+#'   printing. If `NULL`, `getOption("width")` will be consulted.
+#' @param ... Passed to [pillar::glimpse()].
+#'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
+#' `glimpse()` provides an overview (dimensions, column data types, primary
+#' keys, etc.) of all tables included in the `dm` object. It will additionally
+#' print details about outgoing foreign keys for the child table.
+#'
+#' `glimpse()` is provided by the pillar package, and re-exported by {dm}.
+#'  See [pillar::glimpse()] for more details.
+#'
+#' @examples
+#'
+#' dm_nycflights13() %>% glimpse()
+#'
+#' dm_nycflights13() %>%
+#'   dm_zoom_to(flights) %>%
+#'   glimpse()
+#'
 #' @export
 glimpse.dm <- function(x, width = NULL, ...) {
-  glimpse_width <- if (is.null(width)) {
-    getOption("width")
-  } else {
-    width
-  }
+  glimpse_width <- width %||% getOption("width")
+
+  table_names_list <- names(dm_get_tables_impl(x))
+
+  print_glimpse_table_meta(x, glimpse_width)
+  print_rule_between_tables()
+  walk(table_names_list, ~ print_glimpse_table(x, .x, glimpse_width, ...))
+
+  invisible(x)
+}
+
+#' @rdname glimpse.dm
+#' @export
+glimpse.zoomed_dm <- function(x, width = NULL, ...) {
+  glimpse_width <- width %||% getOption("width")
+
+  table_name <- dm_get_zoom(x)$table[[1]]
+
+  print_glimpse_table_meta(x, glimpse_width)
+  print_glimpse_table(x, table_name, glimpse_width, ...)
+
+  invisible(x)
+}
+
+#' Print details about all tables included in the `dm` object (zoomed or not)
+#' @keywords internal
+#' @noRd
+print_glimpse_table_meta <- function(x, width) {
   table_list <- dm_get_tables_impl(x)
+
   if (length(table_list) == 0) {
-    cat_line(trim_width("dm of 0 tables", glimpse_width))
+    cat_line(trim_width("dm of 0 tables", width))
     return(invisible(x))
   }
+
   cat_line(
     trim_width(
       paste0("dm of ", length(table_list), " tables: ", toString(tick(names(table_list)))),
-      glimpse_width
+      width
     )
   )
+}
 
-  all_fks <- dm_get_all_fks_impl(x)
-  iwalk(table_list, function(table, table_name) {
-    cat_line("\n", trim_width(paste0("Table: ", tick(table_name)), glimpse_width))
-    pk <- dm_get_pk_impl(x, table_name) %>%
-      map_chr(~ paste0("(", paste0(tick(.x), collapse = ", "), ")"))
-    if (!is_empty(pk)) {
-      # FIXME: needs to change if #622 is solved
-      cat_line(trim_width(paste0("Primary key: ", pk), glimpse_width))
-    }
-    fk <- all_fks %>%
-      filter(child_table == table_name) %>%
-      select(-child_table) %>%
-      pmap_chr(
-        function(child_fk_cols, parent_table, parent_key_cols, on_delete) {
-          trim_width(
-            paste0(
-              "  (",
-              paste0(tick(child_fk_cols), collapse = ", "), ")",
-              " -> ",
-              "(`", paste0(parent_table, "$", parent_key_cols, collapse = "`, `"), "`) ",
-              on_delete
-            ),
-            glimpse_width
-          )
-        }
-      )
-    if (!is_empty(fk)) {
-      cat_line(length(fk), " outgoing foreign key(s):")
-      cat_line(fk)
-    }
-    glimpse(table, width = width, ...)
-  })
-  invisible(x)
+#' @keywords internal
+#' @noRd
+print_rule_between_tables <- function() {
+  cat("\n")
+  cat_rule()
+}
+
+
+#' Print glimpse for a single table included in the `dm` object (zoomed or not)
+#' @keywords internal
+#' @noRd
+print_glimpse_table <- function(x, table_name, width, ...) {
+  if (is_zoomed(x)) {
+    table <- dm_get_zoom(x)$zoom[[1]]
+  } else {
+    table <- x[[table_name]]
+  }
+
+  # `print_glimpse_table_meta()` is not part of this because it needs to be
+  # printed only once for the entire object
+  print_glimpse_table_name(x, table_name, width)
+  print_glimpse_table_pk(x, table_name, width)
+  print_glimpse_table_fk(x, table_name, width)
+  # emtpy line to demarcate clearly information about keys and the glimpse info
+  cat("\n")
+  glimpse(table, width = width, ...)
+  # in case the object is not zoomed, the following will help visually
+  # distinguish between glimpse outputs for individual tables
+  if (!is_zoomed(x)) print_rule_between_tables()
+}
+
+#' Print table name for a given table in the `dm` object (zoomed or not)
+#' @keywords internal
+#' @noRd
+print_glimpse_table_name <- function(x, table_name, width) {
+  if (is_zoomed(x)) {
+    cat_line("\n", trim_width(paste0("Zoomed table: ", tick(table_name)), width))
+  } else {
+    cat_line("\n", trim_width(paste0("Table: ", tick(table_name)), width))
+  }
+}
+
+#' Print details about primary key for a given table in the `dm` object (zoomed or not)
+#' @keywords internal
+#' @noRd
+print_glimpse_table_pk <- function(x, table_name, width) {
+  pk <- dm_get_pk_impl(x, table_name)
+
+  # anticipate that some key columns could have been removed by the user
+  if (is_zoomed(x)) {
+    pk <-
+      update_zoomed_pk(x) %>%
+      pull(column)
+  }
+
+  pk <- pk %>%
+    map_chr(~ collapse_key_names(.x))
+
+  if (!is_empty(pk)) {
+    # FIXME: needs to change if #622 is solved
+    cat_line(trim_width(paste0("Primary key: ", pk), width))
+  }
+}
+
+collapse_key_names <- function(keys, tab = FALSE) {
+  tab <- ifelse(tab, "  ", "")
+  if (length(keys) > 1L) {
+    paste0(tab, "(", paste0(tick(keys), collapse = ", "), ")")
+  } else {
+    paste0(tab, tick(keys), collapse = ", ")
+  }
+}
+
+#' Print details about foreign keys for a given table in the `dm` object (zoomed or not)
+#' @keywords internal
+#' @noRd
+print_glimpse_table_fk <- function(x, table_name, width) {
+  all_fks <- if (is_zoomed(x)) {
+    # anticipate that some key columns could have been removed/renamed by the user
+    update_zoomed_fks(x, table_name, col_tracker_zoomed(x))
+  } else {
+    dm_get_all_fks_impl(x)
+  }
+
+  fk <- all_fks %>%
+    filter(child_table == !!table_name) %>%
+    select(-child_table) %>%
+    pmap_chr(
+      function(child_fk_cols, parent_table, parent_key_cols, on_delete) {
+        trim_width(
+          paste0(
+            collapse_key_names(child_fk_cols, tab = TRUE),
+            " -> ",
+            collapse_key_names(paste0(parent_table, "$", parent_key_cols)),
+            " ",
+            on_delete
+          ),
+          width
+        )
+      }
+    )
+
+  if (!is_empty(fk)) {
+    cat_line(length(fk), " outgoing foreign key(s):")
+    cat_line(fk)
+  }
 }
