@@ -1,5 +1,8 @@
 #' Add foreign keys
 #'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
 #' `dm_add_fk()` marks the specified `columns` as the foreign key of table `table` with
 #' respect to a key of table `ref_table`.
 #' Usually the referenced columns are a primary key in `ref_table`,
@@ -210,6 +213,9 @@ dm_get_fk2_impl <- function(dm, table_name, ref_table_name) {
 
 #' Get foreign key constraints
 #'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
 #' Get a summary of all foreign key relations in a [`dm`].
 #'
 #' @return A tibble with the following columns:
@@ -258,6 +264,9 @@ dm_get_all_fks_impl <- function(dm, parent_table = NULL, ignore_on_delete = FALS
 
 #' Remove foreign keys
 #'
+#' @description
+#' `r lifecycle::badge("stable")`
+#'
 #' `dm_rm_fk()` can remove either one reference between two tables, or multiple references at once (with a message).
 #' An error is thrown if no matching foreign key is found.
 #'
@@ -568,6 +577,22 @@ check_fk <- function(t1, t1_name, colname, t2, t2_name, pk) {
   )
 }
 
+fk_table_to_def_fks <- function(table,
+                                child_table = "child_table",
+                                child_fk_cols = "child_fk_cols",
+                                parent_table = "parent_table",
+                                parent_key_cols = "parent_key_cols") {
+  table %>%
+    group_by(!!ensym(parent_table)) %>%
+    summarize(
+      fks = list_of(new_fk(
+        ref_column = as.list(!!ensym(parent_key_cols)),
+        table = !!ensym(child_table),
+        column = as.list(!!ensym(child_fk_cols)),
+        on_delete = on_delete
+      ))
+    )
+}
 
 # Errors ------------------------------------------------------------------
 
