@@ -18,7 +18,7 @@
 #' Therefore, in-place operation must be requested explicitly with `in_place = TRUE`.
 #' By default, an informative message is given.
 #'
-#' @inheritParams ellipsis::dots_empty
+#' @inheritParams rlang::args_dots_empty
 #' @inheritParams dplyr::rows_insert
 #' @inheritParams dm_examine_constraints
 #' @param x Target `dm` object.
@@ -64,11 +64,11 @@
 #' flights_jan_sqlite <- copy_dm_to(sqlite, flights_jan)
 #'
 #' # Dry run by default:
-#' dm_rows_insert(flights_sqlite, flights_jan_sqlite)
+#' dm_rows_append(flights_sqlite, flights_jan_sqlite)
 #' print(dm_nrow(flights_sqlite))
 #'
 #' # Explicitly request persistence:
-#' dm_rows_insert(flights_sqlite, flights_jan_sqlite, in_place = TRUE)
+#' dm_rows_append(flights_sqlite, flights_jan_sqlite, in_place = TRUE)
 #' print(dm_nrow(flights_sqlite))
 #'
 #' # Second update:
@@ -86,7 +86,7 @@
 #' flights_feb_sqlite <- copy_dm_to(sqlite, flights_feb)
 #'
 #' # Explicit dry run:
-#' flights_new <- dm_rows_insert(
+#' flights_new <- dm_rows_append(
 #'   flights_sqlite,
 #'   flights_feb_sqlite,
 #'   in_place = FALSE
@@ -99,7 +99,7 @@
 #'   dm_examine_constraints()
 #'
 #' # Apply:
-#' dm_rows_insert(flights_sqlite, flights_feb_sqlite, in_place = TRUE)
+#' dm_rows_append(flights_sqlite, flights_feb_sqlite, in_place = TRUE)
 #' print(dm_nrow(flights_sqlite))
 #'
 #' DBI::dbDisconnect(sqlite)
@@ -108,16 +108,31 @@ NULL
 
 #' dm_rows_insert
 #'
-#' `dm_rows_insert()` adds new records via [rows_insert()].
+#' `dm_rows_insert()` adds new records via [rows_insert()] with `conflict = "ignore"`.
+#' Duplicate records will be silently discarded.
+#' This operation requires primary keys on all tables, use `dm_rows_append()`
+#' to insert unconditionally.
+#' @rdname rows-dm
+#' @aliases dm_rows_...
+#' @export
+dm_rows_insert <- function(x, y, ..., in_place = NULL, progress = NA) {
+  check_dots_empty()
+
+  dm_rows(x, y, "insert", top_down = TRUE, in_place, require_keys = TRUE, progress = progress)
+}
+
+#' dm_rows_append
+#'
+#' `dm_rows_append()` adds new records via [rows_append()].
 #' The primary keys must differ from existing records.
 #' This must be ensured by the caller and might be checked by the underlying database.
 #' Use `in_place = FALSE` and apply [dm_examine_constraints()] to check beforehand.
 #' @rdname rows-dm
 #' @export
-dm_rows_insert <- function(x, y, ..., in_place = NULL, progress = NA) {
+dm_rows_append <- function(x, y, ..., in_place = NULL, progress = NA) {
   check_dots_empty()
 
-  dm_rows(x, y, "insert", top_down = TRUE, in_place, require_keys = FALSE, progress = progress)
+  dm_rows(x, y, "append", top_down = TRUE, in_place, require_keys = FALSE, progress = progress)
 }
 
 #' dm_rows_update
@@ -192,7 +207,7 @@ dm_rows <- function(x, y, operation_name, top_down, in_place, require_keys, prog
   dm_rows_check(x, y)
 
   if (is_null(in_place)) {
-    message("Not persisting, use `in_place = FALSE` to turn off this message.")
+    inform("Result is returned as a dm object with lazy tables. Use `in_place = FALSE` to mute this message, or `in_place = TRUE` to write to the underlying tables.")
     in_place <- FALSE
   }
 
@@ -237,15 +252,40 @@ check_keys_compatible <- function(x, y) {
 
 get_dm_rows_op <- function(operation_name) {
   switch(operation_name,
-    "insert"   = list(fun = rows_insert, pb_label = "inserting rows"),
-    "update"   = list(fun = rows_update, pb_label = "updating rows"),
-    "patch"    = list(fun = rows_patch, pb_label = "patching rows"),
-    "upsert"   = list(fun = rows_upsert, pb_label = "upserting rows"),
-    "delete"   = list(fun = rows_delete, pb_label = "deleting rows"),
+    "insert"   = list(fun = do_rows_insert, pb_label = "inserting rows"),
+    "append"   = list(fun = do_rows_append, pb_label = "appending rows"),
+    "update"   = list(fun = do_rows_update, pb_label = "updating rows"),
+    "patch"    = list(fun = do_rows_patch, pb_label = "patching rows"),
+    "upsert"   = list(fun = do_rows_upsert, pb_label = "upserting rows"),
+    "delete"   = list(fun = do_rows_delete, pb_label = "deleting rows"),
     "truncate" = list(fun = rows_truncate_, pb_label = "truncating rows")
   )
 }
 
+do_rows_insert <- function(x, y, by = NULL, ...) {
+  rows_insert(x, y, by = by, ..., conflict = "ignore")
+}
+
+do_rows_append <- function(x, y, by = NULL, ...) {
+  rows_append(x, y, ...)
+}
+
+do_rows_update <- function(x, y, by = NULL, ...) {
+  rows_update(x, y, by = by, ..., unmatched = "ignore")
+}
+
+do_rows_patch <- function(x, y, by = NULL, ...) {
+  rows_patch(x, y, by = by, ..., unmatched = "ignore")
+}
+
+do_rows_upsert <- function(x, y, by = NULL, ...) {
+  rows_upsert(x, y, by = by, ...)
+}
+
+do_rows_delete <- function(x, y, by = NULL, ...) {
+  rows_delete(x, y, by = by, ..., unmatched = "ignore")
+}
+
 dm_rows_run <- function(x, y, rows_op_name, top_down, in_place, require_keys, progress = NA) {
   # topologically sort tables
   graph <- create_graph_from_dm(x, directed = TRUE)
@@ -258,8 +298,8 @@ dm_rows_run <- function(x, y, rows_op_name, top_down, in_place, require_keys, pr
 
   if (require_keys) {
     all_pks <- dm_get_all_pks(x)
-    if (!nrow(all_pks)) {
-      abort(glue("`dm_rows_{rows_op_name}()` requires the 'dm' object to have primary keys but none were found."))
+    if (!(all(tables %in% all_pks$table))) {
+      abort(glue("`dm_rows_{rows_op_name}()` requires the 'dm' object to have primary keys for all target tables."))
     }
     keys <- deframe(dm_get_all_pks(x))[tables]
   } else {
