@@ -1,5 +1,6 @@
 .onLoad <- function(libname, pkgname) {
   backports::import(pkgname, c("...length"))
+  backports::import(pkgname, c("...names"))
 
   if (getRversion() >= "3.4") {
     dm_financial <<- memoise::memoise(dm_financial, cache = cache_attach())
@@ -14,15 +15,16 @@
 
   register_pkgdown_methods()
 
+  check_version_on_load
   s3_register("waldo::compare_proxy", "dm")
 
-  check_version_on_load("RSQLite", "2.2.8", "to use the {.code returning} argument in {.code dm::rows_*()}")
+  check_version_on_load("RSQLite", "2.2.8", "to use the {.code returning} argument in {.code rows_*()}.")
+  check_version_on_load("dbplyr", "2.2.0", "to use the {.code rows_*()} functions.")
 
   # rigg(enum_pk_candidates_impl)
   # rigg(build_copy_data)
   # rigg(dm_insert_zoomed_outgoing_fks)
   # rigg(dm_upgrade)
-  # rigg(validate_dm)
   # rigg(check_df_structure)
   # rigg(dm_insert_zoomed)
   # rigg(dm_select_tbl_impl)
@@ -37,7 +39,7 @@ rigg <- function(fun) {
 
   rig <- get("rig", asNamespace("boomer"), mode = "function")
 
-  assign(name, rig(fun, ignore = c("~", "{", "(", "<-", "<<-")), getNamespace("dm"))
+  assign(name, rig(fun, ignore = c("~", "{", "(")), getNamespace("dm"))
 }
 
 check_version_on_load <- function(package, version, reason) {
