@@ -96,16 +96,25 @@ my_test_src <- function() {
   )
 }
 
-sqlite_test_src %<--% dbplyr::src_dbi(DBI::dbConnect(RSQLite::SQLite(), ":memory:"), auto_disconnect = TRUE)
+my_test_con <- function() {
+  # FIXME: Remove my_test_src()
+  con_from_src_or_con(my_test_src())
+}
+
+duckdb_test_src %<--% dbplyr::src_dbi(DBI::dbConnect(duckdb::duckdb()), auto_disconnect = TRUE)
 
 my_db_test_src <- function() {
   if (is_db_test_src()) {
     my_test_src()
   } else {
-    sqlite_test_src()
+    duckdb_test_src()
   }
 }
 
+my_db_test_con <- function() {
+  con_from_src_or_con(my_db_test_src())
+}
+
 test_src_frame <- function(..., .temporary = TRUE, .env = parent.frame(), .unique_indexes = NULL) {
   src <- my_test_src()
 
@@ -154,7 +163,7 @@ test_db_src_frame <- function(..., .temporary = TRUE, .env = parent.frame(),
 # for examine_cardinality...() ----------------------------------------------
 
 data_card_1 %<-% tibble::tibble(a = 1:5, b = letters[1:5])
-data_card_1_sqlite %<--% copy_to(sqlite_test_src(), data_card_1())
+data_card_1_duckdb %<--% copy_to(duckdb_test_src(), data_card_1())
 data_card_2 %<-% tibble::tibble(a = c(1, 3:6), b = letters[1:5])
 data_card_3 %<-% tibble::tibble(c = 1:5)
 data_card_4 %<-% tibble::tibble(c = c(1:5, 5L))
@@ -269,12 +278,14 @@ tf_4 %<-% tibble(
 )
 
 tf_5 %<-% tibble(
+  ww = 2L,
   k = 1:4,
   l = letters[2:5],
   m = c("house", "tree", "streetlamp", "streetlamp")
 )
 
 tf_6 %<-% tibble(
+  zz = 1L,
   n = c("house", "tree", "hill", "streetlamp", "garden"),
   o = letters[5:9]
 )
@@ -318,7 +329,7 @@ dm_for_filter_db %<--% {
   copy_dm_to(my_db_test_src(), dm_for_filter())
 }
 
-dm_for_filter_sqlite %<--% copy_dm_to(sqlite_test_src(), dm_for_filter())
+dm_for_filter_duckdb %<--% copy_dm_to(duckdb_test_src(), dm_for_filter())
 
 dm_for_filter_rev %<-% {
   def_dm_for_filter <- dm_get_def(dm_for_filter())
@@ -427,6 +438,7 @@ dm_more_complex %<-% {
 iris_1 %<-% {
   datasets::iris %>%
     as_tibble() %>%
+    mutate(Species = as.character(Species)) %>%
     mutate(key = row_number()) %>%
     select(key, everything())
 }
@@ -526,6 +538,63 @@ dim_4_clean %<-% {
     rename(dim_4.something = something)
 }
 
+# dm for testing dm_disentangle() -----------------------------------------
+
+entangled_dm %<-% {
+  dm(
+    a = tf_5() %>% rename(a = k),
+    b = tf_5() %>% rename(b = k),
+    c = tf_5() %>% rename(c = k),
+    d = tf_5() %>% rename(d = k),
+    e = tf_5() %>% rename(e = k),
+    f = tf_5() %>% rename(f = k),
+    g = tf_5() %>% rename(g = k),
+    h = tf_5() %>% rename(h = k)
+  ) %>%
+    dm_add_pk(b, b) %>%
+    dm_add_pk(c, c) %>%
+    dm_add_pk(d, d) %>%
+    dm_add_pk(e, e) %>%
+    dm_add_pk(f, f) %>%
+    dm_add_pk(g, g) %>%
+    dm_add_pk(h, h) %>%
+    dm_add_fk(a, a, b) %>%
+    dm_add_fk(a, a, c) %>%
+    dm_add_fk(b, b, d) %>%
+    dm_add_fk(c, c, d) %>%
+    dm_add_fk(d, d, e) %>%
+    dm_add_fk(d, d, f) %>%
+    dm_add_fk(e, e, g) %>%
+    dm_add_fk(f, f, g) %>%
+    dm_add_fk(g, g, h)
+}
+
+entangled_dm_2 %<-% {
+  dm(
+    a = tf_5() %>% rename(a = k),
+    b = tf_5() %>% rename(b = k),
+    c = tf_5() %>% rename(c = k),
+    d = tf_5() %>% rename(d = k),
+    e = tf_5() %>% rename(e = k),
+    f = tf_5() %>% rename(f = k),
+    g = tf_5() %>% rename(g = k)
+  ) %>%
+    dm_add_pk(b, b) %>%
+    dm_add_pk(c, c) %>%
+    dm_add_pk(d, d) %>%
+    dm_add_pk(e, e) %>%
+    dm_add_pk(f, f) %>%
+    dm_add_pk(g, g) %>%
+    dm_add_fk(a, a, d) %>%
+    dm_add_fk(b, b, d) %>%
+    dm_add_fk(c, c, d) %>%
+    dm_add_fk(a, a, e) %>%
+    dm_add_fk(d, d, e) %>%
+    dm_add_fk(f, f, g)
+}
+
+# dm_flatten() ------------------------------------------------------------
+
 dm_for_flatten %<-% {
   as_dm(list(
     fact = fact(),
