@@ -5,11 +5,9 @@ test_that("dumma", {
 })
 
 test_that("dm_rows_insert()", {
-  skip_if_ide()
-
   skip_if_not_installed("nycflights13")
   skip_if_not_installed("RSQLite")
-  scoped_options(lifecycle_verbosity = "quiet")
+  local_options(lifecycle_verbosity = "quiet")
 
   expect_snapshot({
     # Entire dataset with all dimension tables populated
@@ -45,11 +43,11 @@ test_that("dm_rows_insert()", {
     flights_hour10_sqlite <- copy_dm_to(sqlite, flights_hour10)
 
     # Dry run by default:
-    out <- dm_rows_insert(flights_sqlite, flights_hour10_sqlite)
+    out <- dm_rows_append(flights_sqlite, flights_hour10_sqlite)
     print(dm_nrow(flights_sqlite))
 
     # Explicitly request persistence:
-    dm_rows_insert(flights_sqlite, flights_hour10_sqlite, in_place = TRUE)
+    dm_rows_append(flights_sqlite, flights_hour10_sqlite, in_place = TRUE)
     print(dm_nrow(flights_sqlite))
 
     # Second update:
@@ -67,7 +65,7 @@ test_that("dm_rows_insert()", {
     flights_hour11_sqlite <- copy_dm_to(sqlite, flights_hour11)
 
     # Explicit dry run:
-    flights_new <- dm_rows_insert(
+    flights_new <- dm_rows_append(
       flights_sqlite,
       flights_hour11_sqlite,
       in_place = FALSE
@@ -80,7 +78,7 @@ test_that("dm_rows_insert()", {
       dm_examine_constraints()
 
     # Apply:
-    dm_rows_insert(flights_sqlite, flights_hour11_sqlite, in_place = TRUE)
+    dm_rows_append(flights_sqlite, flights_hour11_sqlite, in_place = TRUE)
     print(dm_nrow(flights_sqlite))
 
     # Disconnect
@@ -89,10 +87,8 @@ test_that("dm_rows_insert()", {
 })
 
 test_that("dm_rows_update()", {
-  skip_if_ide()
-
-  # https://github.com/duckdb/duckdb/issues/1187
-  skip_if_src("duckdb")
+  # duckdb+df: https://github.com/duckdb/duckdb/issues/4023
+  skip_if_src("duckdb", "maria", "df")
   expect_snapshot({
     # Test bad column order
     dm_filter_rearranged <-
@@ -156,8 +152,6 @@ test_that("dm_rows_update()", {
 })
 
 test_that("dm_rows_truncate()", {
-  skip_if_ide()
-
   expect_snapshot({
     suppressMessages(dm_copy <- copy_dm_to(my_db_test_src(), dm_for_filter()))
 
@@ -209,8 +203,6 @@ test_that("dm_rows_truncate()", {
 # tests for compound keys -------------------------------------------------
 
 test_that("output for compound keys", {
-  skip_if_ide()
-
   skip("COMPOUND")
 
   expect_snapshot({
