@@ -19,12 +19,17 @@ knit_print.grViz <- function(x, ...) {
     knitr::asis_output()
 }
 
-# If input loads dm...
+# If input loads dm or tidyverse, we load it here to omit warnings
 input <- readLines(knitr::current_input())
-if (rlang::has_length(grep("^library[(]dm[)]", input))) {
-  # we load it here to omit warnings
+if (rlang::has_length(grep('^library[(]"?dm"?[)]', input))) {
   library(dm)
 }
+if (rlang::has_length(grep('^library[(]"?tidyverse"?[)]', input))) {
+  library(tidyverse)
+}
+if (rlang::has_length(grep('^library[(]"?dplyr"?[)]', input))) {
+  library(tidyverse)
+}
 
 ## Link helper to enable links only on pkgdown
 href <- function(title, url) {
